﻿using System.Windows.Controls;
using System.Windows.Media;

using Telerik.Windows.Controls;
using Telerik.Windows.Controls.Diagrams;
using Telerik.Windows.Diagrams.Core;

namespace SimpleMM
{
	public partial class MainPage
	{

		public MainPage()
		{
			InitializeComponent();
			this.Loaded += MainPageLoaded;
		}

		void MainPageLoaded(object sender, System.Windows.RoutedEventArgs e)
		{
			this.CreateSampleMindmap();
		}

		private void CreateSampleMindmap()
		{

			// create some shapes
			var root = GetShape("Telerik");
			// just to emphasize the root
			root.Geometry = ShapeFactory.GetShapeGeometry(CommonShapeType.EllipseShape);
			root.Background = KnownBrushes.Green;
			root.Foreground = KnownBrushes.White;
			root.BorderBrush = KnownBrushes.Green;
			var xaml = GetShape("XAML");
			var other = GetShape("Other");
			var web = GetShape("Web");
			var wpf = GetShape("WPF");
			var sl = GetShape("Silverlight");
			var kendo = GetShape("Kendo UI");
			var mvc = GetShape("ASP.Net MVC");
			var ajax = GetShape("ASP.Net Ajax");
			var wf = GetShape("WinForms");
			var rep = GetShape("Reporting");
			var oa = GetShape("OpenAccess");

			// connect them
			this.Connect(root, xaml);
			this.Connect(root, web);
			this.Connect(root, other);

			this.Connect(xaml, wpf);
			this.Connect(xaml, sl);

			this.Connect(web, kendo);
			this.Connect(web, mvc);
			this.Connect(web, ajax);

			this.Connect(other, wf);
			this.Connect(other, rep);
			this.Connect(other, oa);

			//layout
			var settings = new TreeLayoutSettings
			{
				TreeLayoutType = TreeLayoutType.MindmapHorizontal,
				HorizontalSeparation = 80d,
				VerticalSeparation = 70d
			};
			settings.Roots.Add(root);
			this.diagram.Layout(LayoutType.Tree, settings);
			this.diagram.AutoFit();
		}
		private void Connect(IShape from, IShape to)
		{
			var con = new RadDiagramConnection { Source = from, Target = to };
			this.diagram.Items.Add(con);
		}
		private static Brush GetSomeBrush()
		{
			return new SolidColorBrush(ColorUtilities.RandomBlues);
		}
		private RadDiagramShape GetShape(string content)
		{
			// note that it's crucial to assign some size to the shape in order to make the layout work
			var shape = new RadDiagramShape
			{
				Geometry = ShapeFactory.GetShapeGeometry(CommonShapeType.RoundedRectangleShape),
				Content = content,
				Background = GetSomeBrush(),
				Height = 60d,
				Width = 120d,
				UseGlidingConnector = true // make the connections glide around the edge as fits well with the mindmapping 
			};
			this.diagram.Items.Add(shape);
			return shape;
		}
	}
}
